==> sqlitestudio-3.1.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>GUI Schnittstelle zu SQLiteStudio, ein SQLite Manager.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Aktiviert Debug-Meldungen in der Konsole (erreichbar über F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Leitet Debug-Meldungen in den Standardausgabekanal um (erzwingt den Debugmodus).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation>Leitet Debug-Meldungen in die angegebene Datei um (erzwingt den Debugmodus).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>log file</source>
        <translation>Logdatei</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Aktiviert Lemon Parser Debug-Meldungen für den SQL Codeassistenten.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Aktiviert das Debugging für jede SQL Abfrage, die an eine beliebige Datenbank gesendet wurde.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translatorcomment>Wird &lt;database&gt; bei Ausgabe der Meldung in die aktuelle Datenbankbezeichnung umgewandelt?</translatorcomment>
        <translation>Begrenzt SQL Abfragemeldungen auf folgende Datenbank: &lt;database&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>database</source>
        <translation>Datenbank</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translatorcomment>Was wird hier beendet?</translatorcomment>
        <translation>Listet die in SQLiteStudio installierten Plugins auf und beendet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>SQLiteStudio settings file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Database file to open</source>
        <translation>Zu öffnende Datenbankdatei</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <location filename="../main.cpp" line="110"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
</TS>

==> sqlitestudio-3.2.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>GUI Schnittstelle zu SQLiteStudio, ein SQLite Manager.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Aktiviert Debug-Meldungen in der Konsole (erreichbar über F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Leitet Debug-Meldungen in den Standardausgabekanal um (erzwingt den Debugmodus).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation>Leitet Debug-Meldungen in die angegebene Datei um (erzwingt den Debugmodus).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>log file</source>
        <translation>Logdatei</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Aktiviert Lemon Parser Debug-Meldungen für den SQL Codeassistenten.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Aktiviert das Debugging für jede SQL Abfrage, die an eine beliebige Datenbank gesendet wurde.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translatorcomment>Wird &lt;database&gt; bei Ausgabe der Meldung in die aktuelle Datenbankbezeichnung umgewandelt?</translatorcomment>
        <translation>Begrenzt SQL Abfragemeldungen auf folgende Datenbank: &lt;database&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>database</source>
        <translation>Datenbank</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translatorcomment>Was wird hier beendet?</translatorcomment>
        <translation>Listet die in SQLiteStudio installierten Plugins auf und beendet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>SQLiteStudio settings file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Database file to open</source>
        <translation>Zu öffnende Datenbankdatei</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fehler</translation>
    </message>
</context>
</TS>
